@@ -37,8 +37,8 @@ from functools import partial
 from uuid import uuid4 as uuid
 
 import remt
-from .data import DocumentItem, Items
-from .error import *
+from .data import Items
+from .error import ConfigError, FileError
 from .indexer import ann_text, fmt_ann_text
 from .meta import BASE_DIR, fn_path, cache_dir, read_meta, sync_meta, \
     fn_metadata, create_metadata
