@@ -45,19 +45,35 @@ class Pen(enum.IntEnum):
     """
     BALLPOINT_1 = 2
     BALLPOINT_2 = 15
+    CALIGRAPHY = 21
+    ERASER = 6
+    ERASER_AREA = 8
     FINELINER_1 = 4
     FINELINER_2 = 17
     HIGHLIGHTER_1 = 5
     HIGHLIGHTER_2 = 18
-    ERASER = 6
-    ERASER_AREA = 8
-    SHARP_PENCIL_1 = 7
-    SHARP_PENCIL_2 = 13
+    MARKER_1 = 3
+    MARKER_2 = 16
+    MECHANICAL_PENCIL_1 = 7
+    MECHANICAL_PENCIL_2 = 13
+    PAINTBRUSH_1 = 0
+    PAINTBRUSH_2 = 12
+    PENCIL_1 = 1
+    PENCIL_2 = 14
 
     @classmethod
     def is_highlighter(cls, value: int) -> bool:
         return value in (cls.HIGHLIGHTER_1, cls.HIGHLIGHTER_2)
 
+@enum.unique
+class ColorIndex(enum.IntEnum):
+    """
+    Color index value.
+    """
+    BLACK = 0
+    GREY = 1
+    WHITE = 2
+
 class Color(tp.NamedTuple):
     red: float
     green: float
@@ -80,14 +96,18 @@ Layer = namedtuple('Layer', ['number'])
 class Stroke(tp.NamedTuple):
     number: int
     pen: Pen
-    color: Color
-    width: int
+    color: ColorIndex
+    width: float
     segments: tp.List['Segment']
 
-Segment = namedtuple(
-    'Segment',
-    ['number', 'x', 'y', 'speed', 'direction', 'width', 'pressure'],
-)
+class Segment(tp.NamedTuple):
+    number: int
+    x: float
+    y: float
+    speed: float
+    direction: float
+    width: float
+    pressure: float
 
 DocumentItem = tp.Union[Page, PageEnd, Layer, Stroke, Segment]
 Items = tp.Iterable[DocumentItem]
