@@ -25,7 +25,7 @@ import os.path
 from datetime import datetime
 
 from remt import cmd as r_cmd
-from remt.error import *
+from remt.error import ConfigError
 
 import pytest
 from unittest import mock
