@@ -23,8 +23,8 @@ Tests for reading and parsing reMarkable tablet metadata.
 
 import os.path
 
-from remt import meta as r_meta
-from remt.error import *
+from remt import meta as rmeta
+from remt.error import FileError
 
 import pytest
 from unittest import mock
@@ -34,14 +34,14 @@ def test_fn_path():
     Test creating UUID based path from metadata.
     """
     meta = {'uuid': 'xyz'}
-    result = r_meta.fn_path(meta, base='/x/y', ext='.met')
+    result = rmeta.fn_path(meta, base='/x/y', ext='.met')
     assert '/x/y/xyz.met' == result
 
 def test_read_meta():
     """
     Test reading reMarkable tablet metadata.
     """
-    dir_meta = 'dir'
+    dirmeta = 'dir'
 
     with mock.patch('glob.glob') as mock_glob, \
             mock.patch('json.load') as mock_json_load, \
@@ -66,7 +66,7 @@ def test_read_meta():
             {'visibleName': 'f4'},
             {'pages': 6},
         ]
-        result = r_meta.read_meta(dir_meta)
+        result = rmeta.read_meta(dirmeta)
         assert ['f1', 'f2', 'f3'] == list(result)
         assert {'pages': 3} == result['f1']['content']
         assert {'pages': 4} == result['f2']['content']
@@ -79,15 +79,15 @@ def test_fn_metadata_error():
     meta = {'a/b/': 1}
 
     with pytest.raises(FileError):
-        r_meta.fn_metadata(meta, 'x/y')
+        rmeta.fn_metadata(meta, 'x/y')
 
 def test_is_meta():
     """
     Test if a filename is reMarkable tablet meta file.
     """
-    assert r_meta.is_meta('x.content')
-    assert r_meta.is_meta('x.metadata')
-    assert not r_meta.is_meta('x.pdf')
+    assert rmeta.is_meta('x.content')
+    assert rmeta.is_meta('x.metadata')
+    assert not rmeta.is_meta('x.pdf')
 
 def test_find_meta_update():
     """
@@ -111,7 +111,7 @@ def test_find_meta_update():
         'm': 9,
     }
 
-    result = r_meta.find_meta_update(files_remote, files_local)
+    result = rmeta.find_meta_update(files_remote, files_local)
     expected = ['n', 'x']
     assert expected == list(sorted(result))
 
@@ -129,7 +129,7 @@ def test_find_meta_delete():
         'c': 10,
     }
 
-    result = r_meta.find_meta_delete(files_remote, files_local)
+    result = rmeta.find_meta_delete(files_remote, files_local)
     expected = ['a', 'b']
     assert expected == list(sorted(result))
 
@@ -137,12 +137,12 @@ def test_cache_dir():
     """
     Test generating cache directory for reMarkable tablet metadata.
     """
-    with mock.patch.object(r_meta, 'getmac') as mock_getmac_mod, \
+    with mock.patch.object(rmeta, 'getmac') as mock_getmac_mod, \
             mock.patch.object(os.path, 'expanduser') as mock_expand:
 
         mock_getmac_mod.get_mac_address.return_value = 'a:b:c'
         mock_expand.return_value = '/home/t-user'
-        result = r_meta.cache_dir('a-host')
+        result = rmeta.cache_dir('a-host')
         assert '/home/t-user/.cache/remt/a:b:c' == result
 
 def test_ls_local():
@@ -165,7 +165,7 @@ def test_ls_local():
             'x/y/2.metadata',
         ]
 
-        result = r_meta.ls_local('a-dir')
+        result = rmeta.ls_local('a-dir')
 
         expected = {
             '1.content': 1,
@@ -190,7 +190,7 @@ async def test_ls_remote():
     sftp.readdir = mock.AsyncMock()
     sftp.readdir.return_value = [create_fn(v) for v in range(1, 5)]
 
-    result = await r_meta.ls_remote(sftp)
+    result = await rmeta.ls_remote(sftp)
     expected = {
         '1.metadata': 1,
         '2.metadata': 2,
