@@ -30,7 +30,7 @@ def test_parse_item():
     """
     # add some trailing bytes, which shall be not read
     data = io.BytesIO(b'\x01\x02\x03\x04\x00\xff')
-    result = r_parser.parse_item(r_parser.FMT_LAYER, data)
+    result = r_parser.FMT_LAYER.parse(data)
     assert (0x04030201,) == result
 
     # still possible to read the rest of the data
