@@ -22,7 +22,7 @@
 Unit tests for `remt` project utilities.
 """
 
-from cytoolz.functoolz import flip
+from cytoolz.functoolz import flip  # type: ignore
 
 from remt.util import split
 
